#
# spec file for package spicetify-cli
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define sname cli
%define binname spicetify
Name:           spicetify-cli
Version:        2.38.4
Release:        bp160.1.6
Summary:        Command-line tool to customize Spotify client
License:        LGPL-2.1-or-later
URL:            https://spicetify.app/
Source0:        %{sname}-%{version}.tar.zst
Source1:        vendor.tar.gz
BuildRequires:  golang-packaging
BuildRequires:  zstd
BuildRequires:  golang(API) >= 1.21

%description
Command-line tool to customize the official Spotify client

%prep
%autosetup -a1 -n %{sname}-%{version}

%build
go build -mod=vendor -buildmode=pie -ldflags="-X 'main.version=%{version}'"
printf "#!/bin/sh\n%{_libdir}/%{name}/%{binname} \"\$@\"" > ./shortcut

%install
install -Dm755 shortcut %{buildroot}%{_bindir}/%{binname}
install -Dm755 %{sname} %{buildroot}%{_libdir}/%{name}/%{binname}
cp -r Themes Extensions CustomApps jsHelper globals.d.ts css-map.json %{buildroot}%{_libdir}/%{name}

find %{buildroot}%{_libdir}/%{name}/ -type f -executable | grep -v %{name}/%{binname} | xargs chmod a-x

%files
%{_bindir}/%{binname}
%dir %{_libdir}/%{name}
%{_libdir}/%{name}/*
%license LICENSE
%doc README.md

%changelog
* Sat Sep 28 2024 jan.kuzilek@suse.com
- Update to version 2.38.4:
  * fix(preprocess): add new regex to catch variable names for context menu
  * chore(sidebarConfig): change how msg is shown
  * fix(new-releases): use hardcoded `queryArtistDiscographyAll` def (#3166)
  * fix(apply): check for old global navbar existence
* Wed Sep 11 2024 jan.kuzilek@suse.com
- Update to version 2.38.3:
  * feat(topbar): cross-version classname support (#3162)
  * feat(wrapper): relay on webpack's `OnChunksLoadedRuntimeModule`
* Mon Sep  9 2024 jan.kuzilek@suse.com
- Update to version 2.38.2:
  * fix(block-updates): block update folder on `macOS`
  * fix(preprocess/contextmenu): fallback when regex doesn't find candicates
  * fix(block-updates): go back one folder
* Sun Sep  8 2024 jan.kuzilek@suse.com
- Update to version 2.38.0:
  * fix(homeConfig): check if `uri` exists too
  * feat(preprocess/contextmenu): simplify matches
  * fix(apply): remove 4th submatch since it's unnecessary
  * fix(navlinks): add support for `1.2.46`'s global navbar
  * feat(apply): add ability to call multiple functions to one file
  * fix(home-config): support up to 1.2.45 (#3161)
  * feat(sidebarConfig): disable functionality when Global navbar is used
  * fix(apply): move expFeatures regex to the `insertExpFeatures`
  * chore(preprocess): remove console log
  * fix(preprocess/contextmenu): adapt regex for `1.2.46`
  * chore(wrapper): change check for `os_name` to `osx`
  * fix(InitPaths): check for `Apps` folder
  * fix(reddit/tabBar): showing context menu in `More`
  * fix(new-releases): use `PlatformAPI` to fetch podcasts
  * fix(sidebarConfig): remove remaining legacy stuff
  * feat(sidebarConfig): remove support for pre-Library X
  * feat: remove support for pre-Library X UI
  * feat: rename `block-updates` to `spotify-updates`
  * feat(wrapper): set buttons heigh for 1.2.45 and older for Library X
  * feat(cmd): add `block-updates` cmd to block spotify updates
  * revert: check for spotify.exe existence instead of app folder
  * chore(deps): bump golang.org/x/net from 0.28.0 to 0.29.0 (#3156)
  * fix(css-map): just fixing a typo (#3152)
* Thu Aug 29 2024 jan.kuzilek@suse.com
- Update to version 2.37.7:
  * fix(wrapper): sanitize text content to remove all strings
  * fix(wrapper): ignore chunks in strings
  * fix(wrapper): fire `platformLoaded` event later
  * feat(css-map): map `search-searchCategory-carouselButtonVisible` (#3146)
  * feat(popupLyrics): add lrclib provider (#3133)
* Sun Aug 25 2024 jan.kuzilek@suse.com
- Update to version 2.37.4:
  * fix(wrapper/webpack): do not return while webpack is loading
  * fix(wrapper): wait until all modules loaded (#3143)
  * fix(preprocess): match more special characters for `_platform`
  * fix(workflows): only run build & linter on main branches (#3137)
  * fix(wrapper): replace find string for `Slider` component (#3134)
  * fix(preprocess): adapt `_platform` regex for `1.2.44`
  * style(lyrics-plus): adjust lyric animation in `karaoke` mode (#3130)
  * chore(deps): bump golang.org/x/net from 0.27.0 to 0.28.0 (#3129)
  * fix(lyrics-plus/genius): remove `encodeURIComponent` (#3131)
  * fix(new-releases): use `50000` as a limit
* Sun Aug 18 2024 Jan Kužílek <jan.kuzilek@suse.com>
- Initial package, version 2.37.1
